@@ -11,14 +11,14 @@ use Digest::SHA qw(sha1_hex);
 use File::Find qw(find);
 use File::Slurp::Tiny qw(read_file write_file);
 use File::Zglob;
-use List::MoreUtils qw(uniq);
+use List::SomeUtils qw(uniq);
 use Moo;
 use Time::Duration::Parse qw(parse_duration);
 use Try::Tiny;
 use strict;
 use warnings;
 
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 
 sub default_conf_names { ( 'tidyall.ini', '.tidyallrc' ) }
 
@@ -545,7 +545,7 @@ Code::TidyAll - Engine for tidyall, your all-in-one code tidier and validator
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
@@ -745,7 +745,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Andy Jack George Hartzell Gregory Oschwald Joe Crotty Mark Fowler Grimes Olaf Alders Pedro Melo Ricardo Signes Sergey Romanov timgimyee
+=for stopwords Andy Jack George Hartzell Gregory Oschwald Joe Crotty Mark Fowler Grimes Mohammad S Anwar Olaf Alders Pedro Melo Ricardo Signes Sergey Romanov timgimyee
 
 =over 4
 
@@ -775,6 +775,10 @@ Mark Grimes <mgrimes@cpan.org>
 
 =item *
 
+Mohammad S Anwar <mohammad.anwar@yahoo.com>
+
+=item *
+
 Olaf Alders <olaf@wundersolutions.com>
 
 =item *
