@@ -5,11 +5,11 @@ use File::Slurp::Tiny qw(read_file write_file);
 use File::Which qw( which );
 use IPC::Run3 qw( run3 );
 use Scalar::Util qw(weaken);
-use Text::Diff qw( diff );
+use Text::Diff 1.44 qw( diff );
 
 use Moo;
 
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 
 # External
 has 'argv'               => ( is => 'ro', default => q{} );
@@ -189,7 +189,7 @@ Code::TidyAll::Plugin - Create plugins for tidying or validating code
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
