@@ -3,13 +3,13 @@ package Code::TidyAll::Plugin::PodSpell;
 use Capture::Tiny qw();
 use IPC::System::Simple qw();
 use IPC::Run3;
-use List::MoreUtils qw(uniq);
+use List::SomeUtils qw(uniq);
 use Pod::Spell;
 use Moo;
 use Text::ParseWords qw(shellwords);
 extends 'Code::TidyAll::Plugin';
 
-our $VERSION = '0.40';
+our $VERSION = '0.41';
 
 has 'ispell_argv' => ( is => 'ro', default => q{} );
 has 'ispell_cmd'  => ( is => 'ro', default => 'ispell' );
@@ -58,7 +58,7 @@ Code::TidyAll::Plugin::PodSpell - Use Pod::Spell + ispell with tidyall
 
 =head1 VERSION
 
-version 0.40
+version 0.41
 
 =head1 SYNOPSIS
 
